# jwt-tui

jwt-tui is a simple TUI application for quickly decoding the headers and payload of a JWT.

## Install via pip

```sh
pip install jwt-tui
```

## Run

```sh
jwt_tui
```

## Usage

You can provide the token when launching by adding it as an argument:

```sh
jwt_tui TOKEN_STRING
```
